pub struct Pooled<T> { /* private fields */ }Expand description
RAII guard that returns the object to the pool on drop.
This guard can be sent to other threads. When dropped, the object
is automatically returned to the pool’s storage. If the pool was
already dropped, the value goes back into the orphaned Inner,
which finally dies (along with every in-pool value) when the last
Pooled exits. See docs/caveats.md 2.